/**
 * $Id: scaleio.h,v 1.3 2004/07/09 09:43:58 jklein Exp $
 * $Author: jklein $
 * $Log: scaleio.h,v $
 * Revision 1.3  2004/07/09 09:43:58  jklein
 * few small changes.
 *
 * Revision 1.2  2004/06/26 06:58:13  jklein
 * small fix in each header files.
 *
 * Revision 1.1  2004/06/26 06:29:20  jklein
 * Added sort function and IO utilities.
 *
 */


#ifndef _SCALE_SCALEIO_H_
#define _SCALE_SCALEIO_H_

#include <stdio.h>
#include <stdarg.h>
#include <sys/param.h>

#include "scale/commons.h"
#include "scale/buffer.h"


typedef struct _sc_file sfile_t;

int		s_writef(int fd, const char *fmt, ...);
int		s_vwritef(int fd, const char *fmt, va_list ap);
size_t	s_fullwrite(int fd, const void *buf, size_t count);

size_t  s_freadline(FILE *fp, sbuffer_t *buff);
size_t	s_freadfile(FILE *fp, sbuffer_t *buff);



#endif /* _SCALE_SCALEIO_H_ */
